@@ -85,7 +85,7 @@ EOD;
     /* UID */
     $tag["<<SEARCH_UID>>"] ="";
     if (isset($form_name)) {
-        $tag["<<SEARCH_UID>>"] = htmlspecialchars($form_name);
+        $tag["<<SEARCH_UID>>"] = escape_html($form_name);
     }
 
     /* ޥå */
@@ -218,7 +218,7 @@ function set_loop_tag($ldap_result, $filter, $page, $form_name_encode, &$looptag
         $userdn = $ldap_result[$i]["dn"];
         $userdn = base64_encode($userdn);
         $userdn = str_rot13($userdn);
-        $userdn = htmlspecialchars($userdn);
+        $userdn = escape_html($userdn);
 
         /*  */
         $alias = "";
@@ -226,11 +226,11 @@ function set_loop_tag($ldap_result, $filter, $page, $form_name_encode, &$looptag
         $quota = "";
 
         /* 桼̾Ǽ */
-        $name = htmlspecialchars($ldap_result[$i][$dispusr][0]);
+        $name = escape_html($ldap_result[$i][$dispusr][0]);
 
         /* ꥢǼ */
         if (isset($ldap_result[$i]["mailAlias"])) {
-            $mailalias = htmlspecialchars($ldap_result[$i]["mailAlias"][0]);
+            $mailalias = escape_html($ldap_result[$i]["mailAlias"][0]);
             $part = explode("@", $mailalias, 2);
             $alias = $part[0];
         }
@@ -600,7 +600,7 @@ if ($status == STATUS_SEARCH) {
 
         /* ¾Υڡۤåɽ */
         if (isset($_POST["msg"])) {
-            $err_msg = htmlspecialchars($_POST["msg"]);
+            $err_msg = escape_html($_POST["msg"]);
         }
     }
 }
